@@ -663,7 +663,7 @@ moblin_netbook_draw_box_gap (GtkStyle       *style,
                              gint            gap_width)
 {
   cairo_t *cr;
-  GdkRectangle rect;
+  GdkRectangle rect = { 0, };
 
   if (shadow_type == GTK_SHADOW_NONE)
     return;
@@ -1115,7 +1115,26 @@ moblin_netbook_draw_layout (GtkStyle        *style,
       gdk_gc_set_clip_rectangle (gc, area);
     }
 
-  gdk_draw_layout (window, gc, x, y, layout);
+  if (DETAIL ("accellabel") && state_type == GTK_STATE_NORMAL)
+    {
+      cairo_t *cr;
+
+      cr = moblin_netbook_cairo_create (window, area);
+
+      cairo_set_source_rgba (cr,
+                             style->fg[state_type].red / 65535.0,
+                             style->fg[state_type].green / 65535.0,
+                             style->fg[state_type].blue / 65535.0,
+                             0.5);
+      cairo_move_to (cr, x, y);
+      pango_cairo_show_layout (cr, layout);
+      cairo_stroke (cr);
+
+      cairo_destroy (cr);
+
+    }
+  else
+    gdk_draw_layout (window, gc, x, y, layout);
 
   if (area)
     {
@@ -1270,6 +1289,66 @@ moblin_netbook_render_icon (GtkStyle            *style,
   return stated;
 }
 
+static void
+moblin_netbook_draw_expander (GtkStyle         *style,
+                              GdkWindow        *window,
+                              GtkStateType      state_type,
+                              GdkRectangle     *area,
+                              GtkWidget        *widget,
+                              const gchar      *detail,
+                              gint              x,
+                              gint              y,
+                              GtkExpanderStyle  expander_style)
+{
+  cairo_t *cr;
+
+  cr = moblin_netbook_cairo_create (window, area);
+
+  x -= 6;
+  y -= 6;
+
+
+  cairo_set_source_rgba (cr, 0.6, 0.6, 0.6, 0.6);
+  moblin_netbook_rounded_rectangle (cr, x, y, 12, 12, 2 );
+  cairo_stroke_preserve (cr);
+
+  if (state_type == GTK_STATE_PRELIGHT || state_type == GTK_STATE_ACTIVE)
+    cairo_set_source_rgba (cr, 0, 0.6, 0.8, 1);
+  else
+    cairo_set_source_rgba (cr, 1, 1, 1, 1);
+
+  cairo_fill (cr);
+
+  if (state_type == GTK_STATE_PRELIGHT || state_type == GTK_STATE_ACTIVE)
+    cairo_set_source_rgba (cr, 1, 1, 1, 1);
+  else
+    cairo_set_source_rgba (cr, 0, 0.6, 0.8, 1);
+
+  cairo_move_to (cr, x + 2, y + 6);
+  cairo_line_to (cr, x + 10, y + 6);
+  cairo_stroke (cr);
+
+  if (expander_style != GTK_EXPANDER_EXPANDED)
+    {
+      if (expander_style == GTK_EXPANDER_SEMI_COLLAPSED
+          || expander_style == GTK_EXPANDER_SEMI_EXPANDED)
+        {
+          if (state_type == GTK_STATE_PRELIGHT
+              || state_type == GTK_STATE_ACTIVE)
+            cairo_set_source_rgba (cr, 1, 1, 1, 0.5);
+          else
+            cairo_set_source_rgba (cr, 0, 0.6, 0.8, 0.5);
+        }
+
+      cairo_move_to (cr, x + 6, y + 2);
+      cairo_line_to (cr, x + 6, y + 10);
+      cairo_stroke (cr);
+    }
+
+  cairo_destroy (cr);
+}
+
+
 static void
 moblin_netbook_init_from_rc (GtkStyle   *style,
                              GtkRcStyle *rc_style)
@@ -1341,6 +1420,7 @@ moblin_netbook_style_class_init (MoblinNetbookStyleClass *klass)
   style_class->draw_resize_grip = moblin_netbook_draw_resize_grip;
   style_class->draw_layout = moblin_netbook_draw_layout;
   style_class->render_icon = moblin_netbook_render_icon;
+  style_class->draw_expander = moblin_netbook_draw_expander;
 }
 
 static void
